@@ -1071,6 +1071,15 @@ native_string local_filesys::get_final_link_target(native_string const& path)
 	return target;
 }
 
+file::file_t local_filesys::fd()
+{
+#ifdef FZ_WINDOWS
+	return dir_;
+#else
+	return dir_ ? dirfd(dir_) : -1;
+#endif
+}
+
 native_string local_filesys::get_link_target(native_string const& path)
 {
 	native_string target;
